<?php
// ----------------------------------------------------------------------
// MD-Pro Content Management System
// Copyright (C) 2003 by the MaxDev Development Team.
// http://www.maxdev.com/
// ----------------------------------------------------------------------
// Based on:
// Postnuke Content Management System - www.postnuke.com
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE
// This program is free software and it's released under the terms of the
// GNU General Public License(GPL) - http://www.gnu.org/licenses/gpl.html
// Please READ carefully the Docs/License.txt file for further details
// Please READ the Docs/credits.txt file for complete credits list
// ----------------------------------------------------------------------
// Original Author of file: Jim McDonald
// Purpose of file:  Initialisation functions for autolinks
// ----------------------------------------------------------------------

/**
 * initialise the autolinks module
 */
function autolinks_init()
{
	global $pnconfig;
    $dbtype = $pnconfig['dbtype'];
	$prefix = $GLOBALS[prefix];

    // Set up database tables
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    $autolinkstable = $pntable['autolinks'];
    $autolinkscolumn = $pntable['autolinks_column'];

    // See if there is an old autolinks table,
    // probably from an old PN install where autolinks
    // were in the core
    $sql = "SELECT COUNT(1) FROM $autolinkstable";
    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        // There was not, create table

//modified for Oracle compatibility
		switch ($dbtype){
			case "oci8":
		        $sql = "CREATE TABLE $autolinkstable (".
					substr_replace($autolinkscolumn[lid],'',0,strlen($autolinkstable)+1)." INTEGER  NOT NULL,".
					substr_replace($autolinkscolumn[keyword],'',0,strlen($autolinkstable)+1)." VARCHAR2 (100) default '',".
					substr_replace($autolinkscolumn[title],'',0,strlen($autolinkstable)+1)." VARCHAR2 (100) default '',".
					substr_replace($autolinkscolumn[url],'',0,strlen($autolinkstable)+1)." VARCHAR2 (200) default '',".
					substr_replace($autolinkscolumn[comment],'',0,strlen($autolinkstable)+1)." VARCHAR2 (200) default '' , 
					CONSTRAINT AUTOLINKS_PK PRIMARY KEY ( PN_LID ) )"; 			

				$dbconn->Execute($sql);
			    if ($dbconn->ErrorNo() != 0) {
					pnSessionSetVar('errormsg', _DBCREATETABLEERROR);
		            return false;
				}
				$sql2='CREATE SEQUENCE AUTOLINKS_SQ INCREMENT BY 1 START WITH 1 NOCYCLE CACHE 20 NOORDER';
				$dbconn->Execute($sql2);
			    if ($dbconn->ErrorNo() != 0) {
					pnSessionSetVar('errormsg', _DBCREATETABLEERROR);
		            return false;
				}
				$sql3='CREATE OR REPLACE TRIGGER autolinks_tr BEFORE INSERT ON '.$prefix.'_AUTOLINKS FOR EACH ROW WHEN (NEW.pn_lid IS NULL OR NEW.pn_lid = 0) BEGIN  SELECT autolinks_sq.NEXTVAL INTO :NEW.pn_lid FROM dual; END; ';
				$dbconn->Execute($sql3);
			    if ($dbconn->ErrorNo() != 0) {
					pnSessionSetVar('errormsg', _DBCREATETABLEERROR);
		            return false;
				}
				break;
			default:
        $sql = "CREATE TABLE $autolinkstable (
                $autolinkscolumn[lid] INT(11) NOT NULL auto_increment,
                $autolinkscolumn[keyword] VARCHAR(100) NOT NULL default '',
                $autolinkscolumn[title] VARCHAR(100) NOT NULL default '',
                $autolinkscolumn[url] VARCHAR(200) NOT NULL default '',
                $autolinkscolumn[comment] VARCHAR(200) NOT NULL default '',
                PRIMARY KEY (pn_lid),
                UNIQUE KEY keyword (pn_keyword))";
        $dbconn->Execute($sql);

        if ($dbconn->ErrorNo() != 0) {
            pnSessionSetVar('errormsg', _DBCREATETABLEERROR);
            return false;
        }
				break;
		}
    }

    // Set up module variables
    pnModSetVar('Autolinks', 'itemsperpage', 20);
    pnModSetVar('Autolinks', 'linkfirst', 1);
    pnModSetVar('Autolinks', 'invisilinks', 0);

    // Set up module hooks
    if (!pnModRegisterHook('item',
                           'transform',
                           'API',
                           'Autolinks',
                           'user',
                           'transform')) {
        pnSessionSetVar('errormsg', _AUTOLINKSCOULDNOTREGISTER);
        return false;
    }

    // Initialisation successful
    return true;
}

/**
 * upgrade the smiley module from an old version
 */
function autolinks_upgrade($oldversion)
{
    // Upgrade dependent on old version number
    switch($oldversion) {    	
    	case 1.0:
    		// upgrade module type from 1 to 2
    		
    		list($dbconn) = pnDBGetConn();
            $pntable = pnDBGetTables();
			
			$modulestable = $pntable['modules'];
            $modulescolumn = &$pntable['modules_column'];
            
            $sql = "UPDATE $modulestable SET $modulescolumn[type]='2' WHERE $modulescolumn[name]='Autolinks'";

            $dbconn->Execute($sql);
            // Check for an error with the database code, and if so set an
            // appropriate error message and return
            if ($dbconn->ErrorNo() != 0) {
            	//echo $dbconn->errormsg();
                pnSessionSetVar('errormsg', _UPDATETABLEFAILED);
                return false;
            }

    	break;
    	case 1.01:
    		
    	break;
    }
    return true;
}

/**
 * delete the smiley module
 */
function autolinks_delete()
{
    // Remove module hooks
    if (!pnModUnregisterHook('item',
                             'transform',
                             'API',
                             'Autolinks',
                             'user',
                             'transform')) {
        pnSessionSetVar('errormsg', _AUTOLINKSOULDNOTUNREGISTER);
        return false;
    }

    // Remove module variables
    pnModDelVar('Autolinks', 'invisilinks');
    pnModDelVar('Autolinks', 'linkfirst');
    pnModDelVar('Autolinks', 'itemsperpage');

    // Deletion successful
    return true;
}

?>
