<?php
// ----------------------------------------------------------------------
// MD-Pro Content Management System
// Copyright (C) 2003 by the MaxDev Development Team.
// http://www.maxdev.com/
// ----------------------------------------------------------------------
// Based on:
// Postnuke Content Management System - www.postnuke.com
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE
// This program is free software and it's released under the terms of the
// GNU General Public License(GPL) - http://www.gnu.org/licenses/gpl.html
// Please READ carefully the Docs/License.txt file for further details
// Please READ the Docs/credits.txt file for complete credits list
// ----------------------------------------------------------------------
// Original Author of file: Jim McDonald
// Purpose of file:  Blocks administration API
// ----------------------------------------------------------------------

function blocks_adminapi_inc($args)
{
    extract($args);

    // Argument check
    if (!isset($bid) || !is_numeric($bid)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', "::$bid", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _BLOCKSNOAUTH);
        return false;
    }


    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];

    // Get info on current position of block
    $sql = "SELECT $blockscolumn[weight],
                   $blockscolumn[position]
            FROM $blockstable
            WHERE $blockscolumn[bid]='" . (int)pnVarPrepForStore($bid)."'";
    $result = $dbconn->Execute($sql);

    if ($result->EOF) {
        pnSessionSetVar('errormsg', "No such block ID $bid");
        return false;
    }
    list($seq, $position) = $result->fields;
    $result->Close();

    // Get info on displaced block
    $sql = "SELECT $blockscolumn[bid],
                   $blockscolumn[weight]
            FROM $blockstable
            WHERE $blockscolumn[weight]<" . pnVarPrepForStore($seq) . "
            AND   $blockscolumn[position]='" . pnVarPrepForStore($position) . "'
            ORDER BY $blockscolumn[weight] DESC";
    $result = $dbconn->SelectLimit($sql, 1);
    if ($result->EOF) {
        pnSessionSetVar('errormsg', "No block directly above that one");
        return false;
    }
    list($altbid, $altseq) = $result->fields;
    $result->Close();

    // Swap sequence numbers
    $sql = "UPDATE $blockstable
            SET $blockscolumn[weight]=$seq
            WHERE $blockscolumn[bid]=$altbid";
    $dbconn->Execute($sql);
    $sql = "UPDATE $blockstable
            SET $blockscolumn[weight]=$altseq
            WHERE $blockscolumn[bid]=$bid";
    $dbconn->Execute($sql);

    return true;
}

function blocks_adminapi_dec($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if (!isset($bid) || !is_numeric($bid)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', "::$bid", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _BLOCKSNOAUTH);
        return false;
    }

    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];

    // Get info on current position of block
    $sql = "SELECT $blockscolumn[weight],
                   $blockscolumn[position]
            FROM $blockstable
            WHERE $blockscolumn[bid]='" . (int)pnVarPrepForStore($bid)."'";
    $result = $dbconn->Execute($sql);

    if ($result->EOF) {
        pnSessionSetVar('errormsg', "No such block ID $bid");
        return false;
    }
    list($seq, $position) = $result->fields;
    $result->Close();

    // Get info on displaced block
    $sql = "SELECT $blockscolumn[bid],
                   $blockscolumn[weight]
            FROM $blockstable
            WHERE $blockscolumn[weight]>'" . pnVarPrepForStore($seq) . "'
            AND   $blockscolumn[position]='" . pnVarPrepForStore($position) . "'
            ORDER BY $blockscolumn[weight] ASC";
    $result = $dbconn->SelectLimit($sql, 1);

    if ($result->EOF) {
        pnSessionSetVar('errormsg', "No block directly below that one");
        return false;
    }
    list($altbid, $altseq) = $result->fields;
    $result->Close();

    // Swap sequence numbers
    $sql = "UPDATE $blockstable
            SET $blockscolumn[weight]=$seq
            WHERE $blockscolumn[bid]=$altbid";
    $dbconn->Execute($sql);
    $sql = "UPDATE $blockstable
            SET $blockscolumn[weight]=$altseq
            WHERE $blockscolumn[bid]=$bid";
    $dbconn->Execute($sql);

    return true;
}

function blocks_adminapi_update($args)
{
	global $pnconfig;
	$dbtype = $pnconfig['dbtype'];
    // Get arguments from argument array
    extract($args);

    // Optional arguments
    if (!isset($url)) {
        $url = '';
    }
    if (!isset($content)) {
        $content = '';
    }

    // Argument check
    if ((!isset($bid) || !is_numeric($bid)) ||
        (!isset($content)) ||
        (!isset($title)) ||
        (!isset($url)) ||
        (!isset($language)) ||
        (!isset($refresh)) ||
        (!isset($position))) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', "$title::$bid", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _BLOCKSNOAUTH);
        return false;
    }

    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];

//modified for Oracle compatibility
/*    $sql = "UPDATE $blockstable
            SET $blockscolumn[content]='" . pnVarPrepForStore($content) . "',
                $blockscolumn[url]='" . pnVarPrepForStore($url) . "',
                $blockscolumn[title]='" . pnVarPrepForStore($title) . "',
                $blockscolumn[position]='" . pnVarPrepForStore($position) . "',
                $blockscolumn[refresh]='" . pnVarPrepForStore($refresh) . "',
                $blockscolumn[blanguage]='" . pnVarPrepForStore($language) . "'
            WHERE $blockscolumn[bid]=" . (int)pnVarPrepForStore($bid);
*/
//	if (strcmp($dbtype,'oci8')== 0) { 
	switch ($dbtype){
		case "oci8":
	    $sql = "UPDATE $blockstable
            SET $blockscolumn[content]=empty_clob(),
                $blockscolumn[url]='" . pnVarPrepForStore($url) . "',
                $blockscolumn[title]='" . pnVarPrepForStore($title) . "',
                $blockscolumn[position]='" . pnVarPrepForStore($position) . "',
                $blockscolumn[refresh]='" . pnVarPrepForStore($refresh) . "',
                $blockscolumn[blanguage]='" . pnVarPrepForStore($language) . "'
            WHERE $blockscolumn[bid]=" . (int)pnVarPrepForStore($bid);
		$result = $dbconn->Execute($sql);	
		$dbconn->updateClob($blockstable,$blockscolumn[content],pnVarPrepForStore($content),$blockscolumn[bid]."=".(int)pnVarPrepForStore($bid));
			break;
		default:
    $sql = "UPDATE $blockstable
            SET $blockscolumn[content]='" . pnVarPrepForStore($content) . "',
                $blockscolumn[url]='" . pnVarPrepForStore($url) . "',
                $blockscolumn[title]='" . pnVarPrepForStore($title) . "',
                $blockscolumn[position]='" . pnVarPrepForStore($position) . "',
                $blockscolumn[refresh]='" . pnVarPrepForStore($refresh) . "',
                $blockscolumn[blanguage]='" . pnVarPrepForStore($language) . "'
            WHERE $blockscolumn[bid]=" . (int)pnVarPrepForStore($bid);
    $dbconn->Execute($sql);
			break;
	}

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _UPDATEFAILED);
        return false;
    }

    return true;
}

function blocks_adminapi_create($args)
{
    // Get arguments from argument array
	global $pnconfig;
	$dbtype = $pnconfig['dbtype'];
	$dbname = $pnconfig['prefix'];
    extract($args);

    // Argument check
    if ((!isset($title)) ||
        (!isset($position)) ||
        (!isset($mid)) ||
        (!isset($language)) ||
        (!isset($bkey))) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', "$title::", ACCESS_ADD)) {
        pnSessionSetVar('errormsg', _BLOCKSNOAUTH);
        return false;
    }

    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];


//modified for Oracle compatibility
/* 
    $nextId = $dbconn->GenId($blockstable);
	$sql = "INSERT INTO $blockstable (
              $blockscolumn[bid],
              $blockscolumn[bkey],
              $blockscolumn[title],
              $blockscolumn[content],
              $blockscolumn[url],
              $blockscolumn[position],
              $blockscolumn[weight],
              $blockscolumn[active],
              $blockscolumn[refresh],
              $blockscolumn[last_update],
              $blockscolumn[blanguage],
              $blockscolumn[mid])
            VALUES (
              " . pnVarPrepForStore($nextId) . ",
              '" . pnVarPrepForStore($bkey) . "',
              '" . pnVarPrepForStore($title) . "',
              '',
              '',
              '" . pnVarPrepForStore($position) . "',
              0.5,
              1,
              3600,
              0,
              '" . pnVarPrepForStore($language) . "',
              " . pnVarPrepForStore($mid) . ")";
*/
	switch ($dbtype){
		case "oci8":
		$sequence=substr_replace($pntable['blocks'],'',0,strlen($dbname)+1).'_sq';
		$nextId = $dbconn->GenId($sequence);
	    $sql = "INSERT INTO $blockstable (
              $blockscolumn[bid],
              $blockscolumn[bkey],
              $blockscolumn[title],
              $blockscolumn[content],
              $blockscolumn[url],
              $blockscolumn[position],
              $blockscolumn[weight],
              $blockscolumn[active],
              $blockscolumn[refresh],
              $blockscolumn[last_update],
              $blockscolumn[blanguage],
              $blockscolumn[mid])
            VALUES (
              " . pnVarPrepForStore($nextId) . ",
              '" . pnVarPrepForStore($bkey) . "',
              '" . pnVarPrepForStore($title) . "',
              empty_clob(),
              '',
              '" . pnVarPrepForStore($position) . "',
              0.5,
              1,
              3600,
		          '',
              '" . pnVarPrepForStore($language) . "',
              " . pnVarPrepForStore($mid) . ")";
//Oracle format for date is yyyy/mm/dd:hh:mi:ssam if not else specified

			break;
		default:
		$nextId = $dbconn->GenId($blockstable);
    $sql = "INSERT INTO $blockstable (
              $blockscolumn[bid],
              $blockscolumn[bkey],
              $blockscolumn[title],
              $blockscolumn[content],
              $blockscolumn[url],
              $blockscolumn[position],
              $blockscolumn[weight],
              $blockscolumn[active],
              $blockscolumn[refresh],
              $blockscolumn[last_update],
              $blockscolumn[blanguage],
              $blockscolumn[mid])
            VALUES (
              " . pnVarPrepForStore($nextId) . ",
              '" . pnVarPrepForStore($bkey) . "',
              '" . pnVarPrepForStore($title) . "',
              '',
              '',
              '" . pnVarPrepForStore($position) . "',
              0.5,
              1,
              3600,
              0,
              '" . pnVarPrepForStore($language) . "',
              " . pnVarPrepForStore($mid) . ")";
			break;
	}

    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _CREATEFAILED);
        return false;
    }

    // Get bid to return
    $bid = $dbconn->PO_Insert_ID($blockstable, $blockscolumn['bid']);

    // Resequence the blocks
    blocks_adminapi_resequence();

    return $bid;
}

function blocks_adminapi_deactivate($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if (!isset($bid) || !is_numeric($bid)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', "::$bid", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _PERMISSIONSNOAUTH);
        return false;
    }

    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];

    // Deactivate
    $sql = "UPDATE $blockstable
            SET $blockscolumn[active] = 0
            WHERE $blockscolumn[bid] = " . (int)pnVarPrepForStore($bid);
    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _DEACTIVATEERROR);
        return false;
    }

    return true;
}

function blocks_adminapi_activate($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if (!isset($bid) || !is_numeric($bid)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', "::$bid", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _PERMISSIONSNOAUTH);
        return false;
    }

    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];

    // Deactivate
    $sql = "UPDATE $blockstable
            SET $blockscolumn[active] = 1
            WHERE $blockscolumn[bid] = '" . (int)pnVarPrepForStore($bid)."'";
    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _ACTIVATEERROR);
        return false;
    }

    return true;
}

function blocks_adminapi_delete($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if (!isset($bid) || !is_numeric($bid)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', "::$bid", ACCESS_DELETE)) {
        pnSessionSetVar('errormsg', _BLOCKSNOAUTH);
        return false;
    }
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];

    $sql = "DELETE FROM $blockstable
            WHERE $blockscolumn[bid]='" . (int)pnVarPrepForStore($bid)."'";
    $dbconn->Execute($sql);

    blocks_adminapi_resequence(array());

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _DELETEERROR);
        return false;
    }

    return true;
}


function blocks_adminapi_resequence()
{
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $blockstable = $pntable['blocks'];
    $blockscolumn = &$pntable['blocks_column'];


    // Get the information
    $query = "SELECT $blockscolumn[bid],
                     $blockscolumn[position],
                     $blockscolumn[weight]
              FROM $blockstable
              ORDER BY $blockscolumn[position],
                       $blockscolumn[weight],
                       $blockscolumn[active] DESC";
    $result = $dbconn->Execute($query);

    // Fix sequence numbers
    $seq=1;
    $lastpos = '';
//modified for Oracle compatibility
//    while(list($bid, $position, $curseq) = $result->fields) {
    while(!$result->EOF ){
		list($bid, $position, $curseq) = $result->fields;

        $result->MoveNext();

        // Reset sequence number if we've changed block position
        if ($lastpos != $position) {
            $seq = 1;
        }
        $lastpos = $position;

        if ($curseq != $seq) {
            $query = "UPDATE $blockstable
                      SET $blockscolumn[weight]=" . pnVarPrepForStore($seq) . "
                      WHERE $blockscolumn[bid]='" . pnVarPrepForStore($bid)."'";
            $dbconn->Execute($query);
        }
        $seq++;
    }
    $result->Close();

    return;
}

/**
 * obtain list of blocks
 * @returns array
 * @return associative array of known modules
 */

function blocks_adminapi_list()
{
    // Security check
    if (!pnSecAuthAction(0, 'Blocks::', '::', ACCESS_ADMIN)) {
        pnSessionSetVar('errormsg', _MODULESAPINOAUTH);
        return false;
    }


   list($dbconn) = pnDBGetConn();
   $pntable = pnDBGetTables();


//  PER MOSTRARE I BLOCCHI
   $pntable = pnDBGetTables();
   $blockstable = $pntable['blocks'];
   $blockscolumn = &$pntable['blocks_column'];

            $sql = "SELECT $blockscolumn[bid],
                           $blockscolumn[bkey],
                           $blockscolumn[title],
                           $blockscolumn[active],
                           $blockscolumn[position]
                FROM $blockstable
                ORDER BY $blockscolumn[title]";
            $result = $dbconn->Execute($sql);

  if ($result->EOF) {
        return false;
    }

    $resarray = array();
//modified for Oracle compatibility
//    while(list($bid, $bkey, $title, $active, $position) = $result->fields) {
	while(!$result->EOF){
		list($bid, $bkey, $title, $active, $position) = $result->fields;
        $result->MoveNext();

        $resarray[] = array('bid' => $bid,
                            'bkey' => $bkey,
                            'title' => $title,
                            'active' => $active,
                            'position' => $position);
    }
    $result->Close();

    return $resarray;

}
?>
