<?php
// ----------------------------------------------------------------------
// MD-Pro Content Management System
// Copyright (C) 2003 by the MaxDev Development Team.
// http://www.maxdev.com/
// ----------------------------------------------------------------------
// ----------------------------------------------------------------------
// Based on:
// Postnuke Content Management System - http://www.postnuke.com 
// PHP-NUKE Web Portal System - http://www.phpnuke.org 
// Thatware - http://www.thatware.org
//----------------------------------------------------------------------
// Portions of this code were developed by members of the MaxDev Development Team for:
// Envolution 1.25 FLS - http://www.envolution.com.
// ----------------------------------------------------------------------
// LICENSE and CREDITS
// This program is free software and it's released under the terms of the
// GNU General Public License(GPL) - http://www.gnu.org/licenses/gpl.html
// Please READ carefully the Docs/License.txt file for further details
// Please READ the Docs/credits.txt file for complete credits list
// ----------------------------------------------------------------------
// Original Author of file: Stefan Koehler
// Purpose of file:  API functions for rtemulti output stream
// last change: 2002/09/24
// ----------------------------------------------------------------------

/**
 * get relevant items for selected module
 * @return array of items, or false on failure
 **/
// args = string(ob_start)=>original,modname
// items = array=>modified

//include_once( "modules/RteMulti/pnRTEHTML.php" );

/**
 * get all RteMulti items
 * @returns array
 * @return array of items, or false on failure
 */
function rtemulti_userapi_getall($args)
{
    //
    extract($args);

    // Optional arguments.
    if (!isset($startnum)) {
        $startnum = 1;
    }
    if (!isset($numitems)) {
        $numitems = -1;
    }

    if ((!isset($startnum)) ||
        (!isset($numitems))) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    $items = array();

    // Security check - important to do this as early on as possible to 
    // avoid potential security holes or just too much wasted processing
    if (!pnSecAuthAction(0, 'RteMulti::', '::', ACCESS_READ)) {
        return $items;
    }

    // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
    // return arrays but we handle them differently.  For pnDBGetConn() we
    // currently just want the first item, which is the official database
    // handle.  For pnDBGetTables() we want to keep the entire tables array
    // together for easy reference later on
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // It's good practice to name the table and column definitions you are
    // getting - $table and $column don't cut it in more complex modules
    $rtemultitable = $pntable['rtemulti'];
    $rtemulticolumn = &$pntable['rtemulti_column'];

    // Get items - the formatting here is not mandatory, but it does make the
    // SQL statement relatively easy to read.  Also, separating out the sql
    // statement from the SelectLimit() command allows for simpler debug
    // operation if it is ever needed
    $sql = "SELECT $rtemulticolumn[rid],
                   $rtemulticolumn[editortype],
                   $rtemulticolumn[modname],
                   $rtemulticolumn[varname],
                   $rtemulticolumn[keystring],
                   $rtemulticolumn[newstring],
				   $rtemulticolumn[comment]
            FROM $rtemultitable
            ORDER BY $rtemulticolumn[modname],$rtemulticolumn[varname]";
    $result = $dbconn->SelectLimit($sql, $numitems, $startnum-1);

    // Check for an error with the database code, and if so set an appropriate
    // error message and return
    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _GETFAILED);
        return false;
    }

    // Put items into result array.  Note that each item is checked
    // individually to ensure that the user is allowed access to it before it
    // is added to the results array
//modified for Oracle compatibility
//	for (; !$result->EOF; $result->MoveNext()) {
	while (!$result->EOF){
        list($rid, $editortype, $modname, $varname, $keystring, $newstring, $comment) = $result->fields;
        if (pnSecAuthAction(0, 'RteMulti::', "::", ACCESS_READ)) {
            $items[] = array('rid' => $rid,
                             'editortype' => $editortype,
                             'modname' => $modname,
                             'varname' => $varname,
                             'keystring' => $keystring,
                             'newstring' => $newstring,
							 'comment' => $comment);
        }
		$result->MoveNext();
    }

    // All successful database queries produce a result set, and that result
    // set should be closed when it has been finished with
    $result->Close();

    // Return the items
    return $items;
}

/**
 * get a specific item
 * @param $args['rid'] id of RteMulti item to get
 * @returns array
 * @return item array, or false on failure
 */
function rtemulti_userapi_get($args)
{
    // Get arguments from argument array - all arguments to this function
    // should be obtained from the $args array, getting them from other places
    // such as the environment is not allowed, as that makes assumptions that
    // will not hold in future versions of PostNuke
    extract($args);

    // Argument check - make sure that all required arguments are present, if
    // not then set an appropriate error message and return
    if (!isset($rid)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
    // return arrays but we handle them differently.  For pnDBGetConn() we
    // currently just want the first item, which is the official database
    // handle.  For pnDBGetTables() we want to keep the entire tables array
    // together for easy reference later on
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // It's good practice to name the table and column definitions you are
    // getting - $table and $column don't cut it in more complex modules
    $rtemultitable = $pntable['rtemulti'];
    $rtemulticolumn = &$pntable['rtemulti_column'];

    // Get item - the formatting here is not mandatory, but it does make the
    // SQL statement relatively easy to read.  Also, separating out the sql
    // statement from the Execute() command allows for simpler debug operation
    // if it is ever needed
    $sql = "SELECT $rtemulticolumn[rid],
				   $rtemulticolumn[editortype],
				   $rtemulticolumn[modname],
				   $rtemulticolumn[varname],
				   $rtemulticolumn[keystring],
				   $rtemulticolumn[newstring],
				   $rtemulticolumn[comment]
            FROM $rtemultitable
            WHERE $rtemulticolumn[rid] = " . pnVarPrepForStore($rid);
    $result = $dbconn->Execute($sql);

    // Check for an error with the database code, and if so set an appropriate
    // error message and return
    if ($dbconn->ErrorNo() != 0) {
        return false;
    }

    // Check for no rows found, and if so return
    if ($result->EOF) {
        return false;
    }

    // Obtain the item information from the result set
    list($rid, $editortype, $modname, $varname, $keystring, $newstring, $comment) = $result->fields;

    // All successful database queries produce a result set, and that result
    // set should be closed when it has been finished with
    $result->Close();

    // Security check - important to do this as early on as possible to avoid
    // potential security holes or just too much wasted processing.  Although
    // this one is a bit late in the function it is as early as we can do it as
    // this is the first time we have the relevant information
    if (!pnSecAuthAction(0, 'RteMulti::', "$modname::$rid", ACCESS_READ)) {
        return false;
    }

    // Create the item array
    $item = array('rid' => $rid,
				  'editortype' => $editortype,
				  'modname' => $modname,
				  'varname' => $varname,
				  'keystring' => $keystring,
				  'newstring' => $newstring,
                  'comment' => $comment);

    // Return the item array
    return $item;
}

function rtemulti_userapi_getinfo($args)
{
    //
    extract($args);

    // Optional arguments.
    if (!isset($startnum)) {
        $startnum = 1;
    }
    if (!isset($numitems)) {
        $numitems = -1;
    }

    if ((!isset($original)) ||
        (!isset($modname))) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

//    return $original;

    $items = array();

    // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
    // return arrays but we handle them differently.  For pnDBGetConn() we
    // currently just want the first item, which is the official database
    // handle.  For pnDBGetTables() we want to keep the entire tables array
    // together for easy reference later on
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // It's good practice to name the table and column definitions you are
    // getting - $table and $column don't cut it in more complex modules
    $rtemultitable = $pntable['rtemulti'];
    $rtemulticolumn = &$pntable['rtemulti_column'];

    // Get items - the formatting here is not mandatory, but it does make the
    // SQL statement relatively easy to read.  Also, separating out the sql
    // statement from the SelectLimit() command allows for simpler debug
    // operation if it is ever needed
    $sql = "SELECT $rtemulticolumn[rid],
                   $rtemulticolumn[editortype],
                   $rtemulticolumn[modname],
                   $rtemulticolumn[varname],
                   $rtemulticolumn[keystring],
                   $rtemulticolumn[newstring]
            FROM $rtemultitable
			WHERE $rtemulticolumn[modname] = '$modname'
            ORDER BY $rtemulticolumn[modname],$rtemulticolumn[varname]";

    $result = $dbconn->SelectLimit($sql, $numitems, $startnum-1);

    // Check for an error with the database code, and if so set an appropriate
    // error message and return
    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _GETFAILED);
        return false;
    }

    // Put items into result array.  Note that each item is checked
    // individually to ensure that the user is allowed access to it before it
    // is added to the results array
//modified for Oracle compatibility
//	for (; !$result->EOF; $result->MoveNext()) {
	while(!$result->EOF){
        list($rid, $editortype, $modname, $varname, $keystring, $newstring) = $result->fields;
            $items[] = array('rid' => $rid,
                             'editortype' => $editortype,
                             'modname' => $modname,
                             'varname' => $varname,
                             'keystring' => $keystring,
                             'newstring' => $newstring);
		$result->MoveNext();
    }

    // All successful database queries produce a result set, and that result
    // set should be closed when it has been finished with
    $result->Close();
// check if there are activations found or RTE should called
	if(count($items)!=0 || pnModGetVar('rtemulti','RteActivate') > -1) {
//	if(count($items)!=0) {
		$modified = rtemulti_pre_transform($original,$items);
	    // Return the modified outstream, send to browser
	    return $modified;
	} else {
	    // Return the original outstream, send to browser
    	return $original;
	}
}

function rtemulti_userapi_transform($args) {
	extract($args);
	return ($objectid);
}

// Include the settings for options and Textarea-Setup
//
function rtemulti_pre_transform($original,$items) {

//global $pnrootpath;
    // Argument check
    if (!isset($original)) {
        pnSessionSetVar('errormsg', _RTE_ARGSERROR);
        return;
    }
	$text = $original;

	$UserLoggedIn = pnUserLoggedIn();
	if ($UserLoggedIn) {
		$username = pnUserGetVar('uname');
		$userid = pnUserGetVar('uid');
	} else {
		$username = 'Anonymous';
		$userid = '1';
	}

	$options = ' ';
	$tasetup = '';
	
	$settings = array();
	$settings = pnConfigGetVar('RteToolbars');
	$bar1 = "BAR1 = [";
	$bar2 = "BAR2 = [";
	$bar3 = "BAR3 = [";
	for($i=1;$i<=10;$i++) {
		for($blocks=1;$blocks<=10;$blocks++) {
			for($order=1;$order<=4;$order++) {
				if($settings[$blocks][$order] == $i) {
					if($order==1) {
						$bar1 .= $blocks.",";
					} else if($order==2) {
						$bar2 .= $blocks.",";
					} else if($order==3) {
						$bar3 .= $blocks.",";
					}
				}
			}
		}
	}
	if(substr($bar1,strlen($bar1)-1,1) == ',') {
		$bar1 = substr($bar1,0,strlen($bar1)-1)."];";
	} else {
		$bar1 = '';
	}
	if(substr($bar2,strlen($bar2)-1,1) == ',') {
		$bar2 = substr($bar2,0,strlen($bar2)-1)."];";
	} else {
		$bar2 = '';
	}
	if(substr($bar3,strlen($bar3)-1,1) == ',') {
		$bar3 = substr($bar3,0,strlen($bar3)-1)."];";
	} else {
		$bar3 = '';
	}
	
	// set some globals stored in module_vars
    $pnrootpath = pnConfigGetVar('fullurl');
    $homedir = pnModGetVar('rtemulti','editorpath');
    $visual = pnModGetVar('rtemulti', 'RteActivate');
//    $dialogbox = pnModGetVar('rtemulti', 'RteDialogBox');
//	if($dialogbox =='') $dialogbox = 0;
    $visualbox = pnModGetVar('rtemulti', 'RteVisualBox');
	if($visualbox =='') $visualbox = 0;
//    $rtesecurity = pnModGetVar('rtemulti', 'RteSecurity');
//	if($rtesecurity =='') $rtesecurity = 0;
    $RTE_height = pnModGetVar('rtemulti', 'RteHeight');
    $RTE_width = pnModGetVar('rtemulti', 'RteWidth');

	if(!isset($visual)) { $visual=0;}
// First built the options-string for editors toolbar (all users)
	$options = ' ';
    $hideButtons = pnConfigGetVar('RteHideButtons');
	$counter = count($hideButtons);
	for ($i=0;$i<=$counter;$i++) {
		$auth = pnUserGetMemberOf($userid,$i);
		if($auth > -1) {
			$options .= $hideButtons[$i];
			break;
		}
	}
	$options .= ' ';
// if RTE is enabled then enhance the output, if RTE activate then change things in the output
	if (pnModGetVar('rtemulti', 'RteEnable')==1 && pnModGetVar('rtemulti','RteActivate')==2) {
// Call for change other things, for RTE we change the TEXTAREA-tags (1 to n)
    if (is_array($items)) {
        foreach ($items as $item) {
	        $text = rtemulti_transform($text,$items,$item);
			if(!empty($item[varname])) {
				$tasetup .= $item[varname].',';
			}
        }
    } else {
        $text = rtemulti_transform($text,$items,$item);
    }
	}
// Insert quickbuild-scripts and -calls for textarea-fields
// must be a check if in $result is a textarea-field. If so modify it.
	If (ereg('<textarea',$text)) {
		If (ereg('</html>',$text)||ereg('</HTML>',$text)) {

			$jslang = jslanguagelist();
			$curlang = $jslang[pnSessionGetVar('lang')];
			include("modules/RteMulti/pnlang/$curlang/global.php");
		//	include("modules/RteMulti/pnlang/$curlang/tables.php");

//			$scripts = "<script type=\"text/javascript\">ROOTPATH='".$pnrootpath."'; QBPATH='".$homedir."'; VISUAL=".$visual."; SECURE=".$rtesecurity."; DIALOGBOX=".$dialogbox.";";
//			$scripts .= "VISUALBOX=".$visualbox."; LANG='$curlang';OPTIONS='PostIt".$options."';TASETUP='".$tasetup."';";
			$scripts = "<script type=\"text/javascript\">ROOTPATH='".$pnrootpath."'; QBPATH='".$homedir."'; VISUAL=".$visual.";";
			$scripts .= "VISUALBOX=".$visualbox."; LANG='$curlang';OPTIONS='".$options."';TASETUP='".$tasetup."';";
			$scripts .= "ADDHEIGHT='".$RTE_height."'; ADDWIDTH='".$RTE_width."';";
			$scripts .= $bar1." ".$bar2." ".$bar3."</script>\n";

			$scripts .= "<script type=\"text/javascript\" src='".$homedir."/htmlarea.js'></script>\n";
			$scripts .= "<script type=\"text/javascript\">\n";
			if($visualbox) {
	      		$scripts .= "HTMLArea.loadPlugin(\"ContextMenu\");\n";
      		}
			if(!ereg('inserttable',$options)) {
				$scripts .= "HTMLArea.loadPlugin(\"TableOperations\");\n";
			}
			$scripts .= "</script>\n";
			$scripts .= "<script type=\"text/javascript\" src='".$homedir."/rte.js'></script>\n";

			If (ereg('</html>',$text)) $text = str_replace('</html>',$scripts.'</html>',$text);
			If (ereg('</HTML>',$text)) $text = str_replace('</HTML>',$scripts.'</HTML>',$text);
//			$scripts2 = "<script src='".$homedir."/rte.js'></script>\n";
//			If (ereg('</body>',$text)) $text = str_replace('</body>',$scripts2.'</body>',$text);
		}
	}
    return $text;
}

// Change and expand the textarea-tags and other things find in the database
// Here it would be possible to hardcode some things
// The main functionality is like the Autolinks-module or bb_anywhere-module
//
function rtemulti_transform($text,$items,$item) {

    extract($item);

    $result = $text;
	
    $homedir = pnModGetVar('rtemulti', 'editorpath');

    // modify original outstream
    //
/** 24.09. *******************************************
	if (substr($item[keystring],0,9)=='<textarea'){
		$NewTag = new pnRTEHTML();
		$NewTag->RTEFormTextArea($item[varname],$item[keystring], 12, 50, $homedir, '');
		$result = str_replace($item[keystring], $NewTag->GetOutput(), $result);
	}
	If (substr($item[keystring],0,5)=='<form') {
		$NewForm = new pnRTEHTML();
// must be a check if in $result is a textarea-field. If so modify it.
		If (ereg('<textarea',$result)) {
			$NewForm->RTEFormStart($item[keystring],'Myform',$items);
			$result = str_replace($item[keystring], $NewForm->GetOutput(), $result);
		}
	}
	
** 24.09. ********************************************/
	If ($item[varname] == '') {
    	$result = str_replace($item[keystring],$item[newstring], $result);
	}

    return $result;
}


?>
