<?php
// ----------------------------------------------------------------------
// MD-Pro Content Management System
// Copyright (C) 2003 by the MaxDev Development Team.
// (Link: http://www.maxdev.com/)http://www.maxdev.com/
// ----------------------------------------------------------------------
// Based on:
// Postnuke Content Management System - www.postnuke.com
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE and CREDITS
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WIthOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------
// Original Author of file: Jim McDonald
// this release: Bas van den Bosch
// Purpose of file:  Initialisation functions for topics
// ----------------------------------------------------------------------

/**
 * initialise the categories module
 * This function is only ever called once during the lifetime of a particular
 * module instance
 */
function topics_init()
{
        global $pnconfig;
        $dbtype = $pnconfig['dbtype'];

        list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // It's good practice to name the table and column definitions you
    // are getting - $table and $column don't cut it in more complex
    // modules
    $topicstable = $pntable['topics'];
    $topicscolumn = &$pntable['topics_column'];

    // Create the table - the formatting here is not mandatory, but it does
    // make the SQL statement relatively easy to read.  Also, separating out
    // the SQL statement from the Execute() command allows for simpler
    // debug operation if it is ever needed
    switch ($dbtype){
            case "oci8":
                        $sql1 = " CREATE TABLE $topicstable ( ".
                                substr_replace($topicscolumn[topicid],'',0,strlen($topicstable)+1)." INTEGER NOT NULL,".
                                substr_replace($topicscolumn[topicnametag],'',0,strlen($topicstable)+1)." VARCHAR2 (32) DEFAULT '', ".
                                substr_replace($topicscolumn[topicexttext],'',0,strlen($topicstable)+1)." CLOB, ".
                                substr_replace($topicscolumn[topictext],'',0,strlen($topicstable)+1)." VARCHAR2 (255), ".
                                substr_replace($topicscolumn[topicimage],'',0,strlen($topicstable)+1)." VARCHAR2 (32) DEFAULT '', ".
                                substr_replace($topicscolumn[topicparent],'',0,strlen($topicstable)+1)." INTEGER DEFAULT '0', ".
                                substr_replace($topicscolumn[topicname],'',0,strlen($topicstable)+1)." VARCHAR2 (255) DEFAULT '', ".
                                substr_replace($topicscolumn[counter],'',0,strlen($topicstable)+1)." INTEGER DEFAULT '0', ".
                              CONSTRAINT SUBJECTS_PK
                                PRIMARY KEY ( topicid ) )";

                        $dbconn->Execute($sql1);

                        if ($dbconn->ErrorNo() != 0) {
                        pnSessionSetVar('errormsg', _CREATETABLEFAILED);
                return false;
                        }

                        $sql2='CREATE SEQUENCE TOPICS_SQ INCREMENT BY 1 START WITH 6 NOCYCLE CACHE 20 NOORDER';
                        $dbconn->Execute($sql2);

                        $sql3='CREATE OR REPLACE TRIGGER topics_tr BEFORE INSERT ON '.$prefix.'_TOPICS FOR EACH ROW WHEN  (NEW.pn_topicid IS NULL OR NEW.pn_topicid = 0) BEGIN SELECT topics_sq.NEXTVAL INTO :NEW.pn_topicid FROM  dual; END; ';
                        $dbconn->Execute($sql3);
                        break;
                default:
                        $sql = "CREATE TABLE $topicstable (
                    $topicscolumn[topicid] INT(10) NOT NULL auto_increment,
                        $topicscolumn[topicnametag] VARCHAR(32) default '',
                            $topicscolumn[topicexttext] TEXT default '',
                    $topicscolumn[topictext] varchar(255) default '',
                        $topicscolumn[topicimage] VARCHAR(32) default '',
                            $topicscolumn[topicparent] INT(10) default 0,
                    $topicscolumn[topicname] varchar(255) default '',
                        $topicscolumn[counter] INT(11) NOT NULL default 0,
                            PRIMARY KEY(pn_topicid))";

                        $dbconn->Execute($sql);

                    // Check for an error with the database code, and if so set an
                    // appropriate error message and return
                    if ($dbconn->ErrorNo() != 0) {
                        pnSessionSetVar('errormsg', _CREATETABLEFAILED);
                        return false;
                    }
                        break;
        }

    // Set up an initial value for a module variable.  Note that all module
    // variables should be initialised with some value in this way rather
    // than just left blank, this helps the user-side code and means that
    // there doesn't need to be a check to see if the variable is set in
    // the rest of the code as it always will be
    pnModSetVar('topics', 'itemsperrow', 5);
    pnModSetVar('topics', 'rowsperpage', 2);
    pnModSetVar('topics', 'usesubtopics', true);
    pnModSetVar('topics', 'maintopictext', '');
    pnModSetVar('topics', 'themedependantimages', false);
    pnModSetVar('topics', 'languagedependantimages', false);
    pnConfigSetVar('tipath', 'modules\Topics\pnimages');

    // Initialisation successful
    return true;
}

/**
 * upgrade the template module from an old version
 * This function can be called multiple times
 */
function topics_upgrade($oldversion)
{
    // Upgrade dependent on old version number
    switch($oldversion) {
        case 1.0:

            list($dbconn) = pnDBGetConn();
            $pntable = pnDBGetTables();

            $topicstable = $pntable['topics'];
            $topicscolumn = &$pntable['topics_column'];

            $sql = "ALTER TABLE $topicstable
                    ADD ".$topicscolumn['topicnametag']." varchar(32) default ''";
            $dbconn->Execute($sql);

            if ($dbconn->ErrorNo() != 0) {
                pnSessionSetVar('errormsg', _UPDATETABLE1FAILED);
                return false;
            }

            $sql = "ALTER TABLE $topicstable
                    ADD ".$topicscolumn['topicparent']." int(10) default 0";
            $dbconn->Execute($sql);

            if ($dbconn->ErrorNo() != 0) {
                pnSessionSetVar('errormsg', _UPDATETABLE2FAILED);
                return false;
            }

            $sql = "ALTER TABLE $topicstable
                    ADD ".$topicscolumn['topicexttext']." TEXT default ''";
            $dbconn->Execute($sql);

            if ($dbconn->ErrorNo() != 0) {
                pnSessionSetVar('errormsg', _UPDATETABLE3FAILED);
                return false;
            }
            //alter topicnametag

            $sql = "UPDATE $topicstable
                    SET ".$topicscolumn['topicnametag']." = ".$topicscolumn['topicname']."";
            $dbconn->Execute($sql);

            if ($dbconn->ErrorNo() != 0) {
                pnSessionSetVar('errormsg', _UPDATETABLE4FAILED);
                return false;
            }


            pnModSetVar('topics', 'itemsperrow', 5);
                    pnModSetVar('topics', 'rowsperpage', 2);
                    pnModSetVar('topics', 'usesubtopics', false);
                    pnModSetVar('topics', 'maintopictext', '');


            // At the end of the successful completion of this function we
            // recurse the upgrade to handle any other upgrades that need
            // to be done.  This allows us to upgrade from any version to
            // the current version with ease
            return topics_upgrade('1.1');
        case 1.1:
            pnModSetVar('topics', 'themedependantimages', false);
                pnModSetVar('topics', 'languagedependantimages', false);
            return topics_upgrade('1.2');
        case 2.0:
            // Code to upgrade from version 2.0 goes here
            break;
    }

    // Update successful
    return true;
}

/**
 * delete the template module
 * This function is only ever called once during the lifetime of a particular
 * module instance
 */
function topics_delete()
{
    // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
    // return arrays but we handle them differently.  For pnDBGetConn()
    // we currently just want the first item, which is the official
    // database handle.  For pnDBGetTables() we want to keep the entire
    // tables array together for easy reference later on
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // Drop the table - for such a simple command the advantages of separating
    // out the SQL statement from the Execute() command are minimal, but as
    // this has been done elsewhere it makes sense to stick to a single method
    $sql = "DROP TABLE $pntable[topics]";
    $dbconn->Execute($sql);

    // Check for an error with the database code, and if so set an
    // appropriate error message and return
    if ($dbconn->ErrorNo() != 0) {
        // Report failed deletion attempt
        return false;
    }

    // Delete any module variables
    pnModDelVar('topics', 'itemsperrow');
    pnModDelVar('topics', 'rowsperpage');
    pnModDelVar('topics', 'usesubtopics');
    pnModDelVar('topics', 'themedependantimages');
    pnModDelVar('topics', 'languagedependantimages');


    // Deletion successful
    return true;
}

?>